@@ -36,6 +36,8 @@ class Company(IngestedDataType):
     locations: Optional[list[Location]] = None
     last_enriched_at: Optional[str] = None
     telescope_icp: Optional[bool] = None
+    uprank: Optional[int] = None
+    downrank: Optional[int] = None
 
     @staticmethod
     def from_pdl(pdl_input: dict[str, any]) -> Optional['Company']:
@@ -78,5 +80,7 @@ class Company(IngestedDataType):
             hq=Location.from_pdl(pdl_location) if pdl_location else None,
             locations=[Location.from_pdl(pdl_location)] if pdl_location else None,
             last_enriched_at=get_current_datetime_aws_format(),
-            telescope_icp=None
+            telescope_icp=None,
+            uprank=None,
+            downrank=None
         )
